Finland
-------
fi/Finnish_monetary_institution_codes_and_BICs_in_excel_format.csv
Source: 
https://www.finanssiala.fi/en/topics/payment-services-in-finland/payment-technical-documents/
->
https://www.finanssiala.fi/wp-content/uploads/2021/03/Finnish_monetary_institution_codes_and_BICs_in_excel_format.xlsx

Sweden
------
se/Swedish-Bankernas-kontonummer.csv
Source: 
https://danskebank.se/privat/produkter/betala/betalningar/bankernas-kontonummer-och-clearingnummer
https://www-2.danskebank.se/link/Bankernaskontonummer
Also for reference:
https://www.bankgirot.se/globalassets/dokument/anvandarmanualer/bankernaskontonummeruppbyggnad_anvandarmanual_sv.pdf

Denmark
-------
dk/danish-bank-codes.csv
Source:
https://github.com/x2q/danish-bank-codes
